@@ -8,8 +8,8 @@ from .table_representation import Table
 from .table_representation import Column
 from .yaml_worker import YamlActionsWorker
 from .yaml_worker import YamlDataBaseWorker
-from sql import SQLite
-from sql import SQL
+from .sql import SQLite
+from .sql import SQL
 
 __all__ = [
     'YamlDataBaseWorker',
